#
# spec file for package python-ghp-import
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-ghp-import
Version:        2.1.0
Release:        5.1
Summary:        Utility to import docs into a gh-pages branch
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://pypi.org/project/ghp-import/
Source:         https://files.pythonhosted.org/packages/source/g/ghp-import/ghp-import-%{version}.tar.gz
BuildRequires:  %{python_module dateutil >= 2.8.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-dateutil >= 2.8.1
BuildArch:      noarch
%python_subpackages

%description
A utility to import docs to a gh-pages branch.
This will destroy the gh-pages branch. This script assumes that
gh-pages is 100%% derivative. You should never edit files in your
gh-pages branch by hand if you're using this script because you
will lose your work.

%prep
%autosetup -n ghp-import-%{version}
sed -i '1d' ghp_import.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ghp-import

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%pre
%python_libalternatives_reset_alternative ghp-import

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/ghp-import
%{python_sitelib}/ghp_import.py
%{python_sitelib}/__pycache__/ghp_import*.pyc
%{python_sitelib}/ghp_import-%{version}*-info

%changelog
* Mon Jun  9 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Tue May 27 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Feb 27 2023 Matej Cepl <mcepl@suse.com>
- Don't use fdupes -s, it hurts.
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.1.0
  * Remove outdated "I" and "me" from the text
  * Use `rfc2822` date format (#109)
  * Respect `--prefix` when using `--no-jekyll` (#107)
  * Remove unused constant
  * Switch from optparse to argparse (#103)
- Update to version 2.0.2
  * Build and release wheels (#102)
* Sat Aug 14 2021 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture and filler wording from description. Use noun
  phrase for summary.
* Fri Aug 13 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 2.0.1
  * Add --version CLI option
  * Include minor fixes
* Wed May 19 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 1.1.0
* Wed Feb  3 2021 ecsos <ecsos@opensuse.org>
- Update to 1.0.1
  - No changelog from upstream.
* Wed Jul  4 2018 ecsos@opensuse.org
- initial version 0.5.5
